@@ -9,4 +9,8 @@
  * See the file "COPYING" for the exact licensing terms.
  */
 
-#define VERSION "0.5.4"
+#define VERSION			"0.6.0.9"
+#define LIBVER_MIN_TRANSPORT	0x00000600
+#define LIBVER_MIN_SCAN		0x00000600
+#define LIBVER_MIN_PLEXTOR	0x00000600
+#define LIBVER_MIN_PIONEER	0x00000600
